==> jc-1.4.0.tar.gz: soot/jimple/internal/JAssignStmt__24LinkedVariableBox.h <==
// class soot.jimple.internal.JAssignStmt$LinkedVariableBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 5f0fe8993708aa5b soot_jimple_internal_JAssignStmt__24LinkedVariableBox
// @dep_class 4d2ec45088a5f0e7 soot_jimple_internal_VariableBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_VariableBox

#include "soot/jimple/internal/VariableBox.h"

#ifndef _JC_soot_jimple_internal_JAssignStmt__24LinkedVariableBox_H_
#define _JC_soot_jimple_internal_JAssignStmt__24LinkedVariableBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_internal_JAssignStmt$object;
struct _jc_soot_jimple_internal_JAssignStmt__241$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object;

typedef const struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$_init$9cace58ac744c51a(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_soot_jimple_internal_JAssignStmt$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$_init$e709d0d728d9911c(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_soot_jimple_internal_JAssignStmt$object *, struct _jc_object *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$setOtherBox$6d08ef9dbd7c1f27(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method_info$canContainValue$dd22978795c5cdfb;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method_info$setOtherBox$6d08ef9dbd7c1f27;

// Virtual methods structure
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *);
	void	(*setOtherBox$6d08ef9dbd7c1f27)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_jimple_internal_VariableBox$vmethods	soot_jimple_internal_VariableBox;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods	soot_jimple_internal_JAssignStmt__24LinkedVariableBox;
};

// Vtype
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs {
	struct _jc_object	*otherBox;
	struct _jc_soot_jimple_internal_JAssignStmt$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs {
    _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs	soot_jimple_internal_JAssignStmt__24LinkedVariableBox;
    _jc_soot_jimple_internal_VariableBox$sub_refs	soot_jimple_internal_VariableBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_jimple_internal_VariableBox$sub_nonrefs	soot_jimple_internal_VariableBox;
    _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs	soot_jimple_internal_JAssignStmt__24LinkedVariableBox;
};

// Object instance structure
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object {
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype	*vtype;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JAssignStmt__24LinkedVariableBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$class_object;

#endif	/* _JC_soot_jimple_internal_JAssignStmt__24LinkedVariableBox_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JAssignStmt__24LinkedVariableBox.h <==
// class soot.jimple.internal.JAssignStmt$LinkedVariableBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class 5f0fe8993708aa5b soot_jimple_internal_JAssignStmt__24LinkedVariableBox
// @dep_class 4d2ec45088a5f0e7 soot_jimple_internal_VariableBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_VariableBox

#include "soot/jimple/internal/VariableBox.h"

#ifndef _JC_soot_jimple_internal_JAssignStmt__24LinkedVariableBox_H_
#define _JC_soot_jimple_internal_JAssignStmt__24LinkedVariableBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_internal_JAssignStmt$object;
struct _jc_soot_jimple_internal_JAssignStmt__241$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs;
typedef struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object;

typedef const struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable;
typedef const struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$_init$9cace58ac744c51a(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_soot_jimple_internal_JAssignStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$_init$e709d0d728d9911c(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_soot_jimple_internal_JAssignStmt$object *, struct _jc_object *, struct _jc_soot_jimple_internal_JAssignStmt__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method$setOtherBox$6d08ef9dbd7c1f27(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method_info$canContainValue$dd22978795c5cdfb;
extern _jc_method _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$method_info$setOtherBox$6d08ef9dbd7c1f27;

// Virtual methods structure
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setOtherBox$6d08ef9dbd7c1f27)(_jc_env *, struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_jimple_internal_VariableBox$vmethods	soot_jimple_internal_VariableBox;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vmethods	soot_jimple_internal_JAssignStmt__24LinkedVariableBox;
};

// Vtype
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs {
	struct _jc_object	*otherBox;
	struct _jc_soot_jimple_internal_JAssignStmt$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs {
    _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_refs	soot_jimple_internal_JAssignStmt__24LinkedVariableBox;
    _jc_soot_jimple_internal_VariableBox$sub_refs	soot_jimple_internal_VariableBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_jimple_internal_VariableBox$sub_nonrefs	soot_jimple_internal_VariableBox;
    _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$sub_nonrefs	soot_jimple_internal_JAssignStmt__24LinkedVariableBox;
};

// Object instance structure
struct _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$object {
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype	*vtype;
	_jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$vtype _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JAssignStmt__24LinkedVariableBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JAssignStmt__24LinkedVariableBox$class_object;

#endif	/* _JC_soot_jimple_internal_JAssignStmt__24LinkedVariableBox_H_ */
